"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var FontFaceObserver = require("fontfaceobserver");
var make_cancelable_1 = require("./make-cancelable");
/**
 * Creates new font observer based on font data
 * @param font - font data to observe
 */
function load(font, timeout) {
    var family = font.family, style = font.style, weight = font.weight, stretch = font.stretch;
    var observer = new FontFaceObserver(family, { style: style, weight: weight, stretch: stretch });
    return make_cancelable_1.default(observer.load(null, timeout));
}
exports.load = load;
/**
 * Map font data for case when font is still waiting to be loaded
 */
function dataWithLoadingFont(_a) {
    var family = _a.family, _b = _a.weight, weight = _b === void 0 ? 'normal' : _b, _c = _a.style, style = _c === void 0 ? 'normal' : _c, _d = _a.stretch, stretch = _d === void 0 ? 'normal' : _d, cssClass = _a.class, styles = _a.styles;
    return {
        family: family,
        weight: weight,
        style: style,
        stretch: stretch,
        class: (cssClass && cssClass.initial) || '',
        styles: (styles && styles.initial) || {},
    };
}
exports.dataWithLoadingFont = dataWithLoadingFont;
/**
 * Map font data for case when font is ready before timeout
 */
function dataWithLoadedFont(font) {
    return __assign({}, font, { timing: font.timing || -1, class: (font.class && font.class.success) || '', styles: (font.styles && font.styles.success) || {} });
}
exports.dataWithLoadedFont = dataWithLoadedFont;
/**
 * Map font data for case when font timeouted to load
 */
function dataWithFailedFont(font) {
    var cssClass = (font.class && (font.class.fallback || font.class.initial)) || '';
    var styles = (font.styles && (font.styles.fallback || font.styles.initial)) || {};
    return __assign({}, font, { class: cssClass, styles: styles, error: font.error || new Error() });
}
exports.dataWithFailedFont = dataWithFailedFont;
exports.noop = function () { }; // tslint:disable-line
//# sourceMappingURL=helpers.js.map