"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var helpers_1 = require("./helpers");
/**
 * Wraps component with HoC and injects user-provided fonts props
 */
function withAsyncFonts(fonts, userOptions) {
    var options = __assign({ onFontTimeout: helpers_1.noop, onFontReady: helpers_1.noop, timeout: 5000 }, userOptions);
    return function (BaseComponent) {
        var originalName = BaseComponent.displayName || BaseComponent.name || 'Component';
        return _a = /** @class */ (function (_super) {
                __extends(WithAsyncFonts, _super);
                function WithAsyncFonts(props) {
                    var _this = _super.call(this, props) || this;
                    _this.promises = [];
                    // Set default state with basic font values
                    _this.state = Object.keys(fonts).reduce(function (state, code) {
                        var font = fonts[code];
                        return __assign({}, state, (_a = {}, _a[code] = helpers_1.dataWithLoadingFont(font), _a));
                        var _a;
                    }, {});
                    return _this;
                }
                WithAsyncFonts.prototype.componentDidMount = function () {
                    var _this = this;
                    var onFontReady = options.onFontReady, onFontTimeout = options.onFontTimeout, timeout = options.timeout;
                    var keys = Object.keys(fonts);
                    // Collect cancelable promises
                    this.promises = keys.reduce(function (promises, code) { return promises.concat([helpers_1.load(fonts[code], timeout)]); }, []);
                    // Resolve fonts
                    this.promises.forEach(function (promise, index) {
                        var timing = Date.now();
                        var key = keys[index];
                        var inputFont = fonts[key];
                        promise
                            .then(function (resolvedFont) {
                            var loadedFont = helpers_1.dataWithLoadedFont(__assign({}, inputFont, resolvedFont, { timing: Date.now() - timing }));
                            _this.setState(function () {
                                return (_a = {}, _a[key] = loadedFont, _a);
                                var _a;
                            }, function () { return (onFontReady ? onFontReady(loadedFont) : null); });
                        })
                            .catch(function (_a) {
                            var isCanceled = _a.isCanceled;
                            if (isCanceled) {
                                return; // Do nothing
                            }
                            var fallbackFont = helpers_1.dataWithFailedFont(inputFont);
                            _this.setState(function () {
                                return (_a = {}, _a[key] = fallbackFont, _a);
                                var _a;
                            }, function () { return (onFontTimeout ? onFontTimeout(fallbackFont) : null); });
                        });
                    });
                };
                WithAsyncFonts.prototype.componentWillUnmount = function () {
                    // Mark all promises as canceled once component is unmounted
                    this.promises.forEach(function (promise) { return (promise.cancel ? promise.cancel() : null); });
                };
                WithAsyncFonts.prototype.render = function () {
                    return React.createElement(BaseComponent, __assign({}, this.props, this.state));
                };
                return WithAsyncFonts;
            }(React.Component)),
            _a.displayName = "withAsyncFonts(" + originalName + ")",
            _a;
        var _a;
    };
}
exports.default = withAsyncFonts;
//# sourceMappingURL=index.js.map